AccelerateEasing class

加速曲线。对应 Kotlin AccelerateEasing。

factor=1 时为 y=x²;factor 越大,缓入越夸张。

Inheritance

Constructors

AccelerateEasing([double factor = 1.0])
const

Properties

factor → double
final
flipped → Curve
Returns a new curve that is the reversed inversion of this one.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(double t) → double
Returns the value of the curve at point t.
inherited
transformInternal(double t) → double
Returns the value of the curve at point t.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited