BlurColors class

模糊后应用的颜色配置。对应 Kotlin BlurColors

blendColors 按顺序叠加在模糊背景上;brightness 亮度调整 -1,1,0 无变化; contrast 对比度乘子,1 无变化;saturation 饱和度乘子,1 无变化。

Annotations

Constructors

BlurColors({List<BlendColorEntry> blendColors = const [], double brightness = 0.0, double contrast = 1.0, double saturation = 1.0})
const

Properties

blendColors List<BlendColorEntry>
final
brightness double
final
contrast double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saturation double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override