Highlight class

高光配置。对应 Kotlin Highlight

width 描边带宽(dp,默认 0.8);alpha 整体不透明度;style 着色模型。

Annotations

Constructors

Highlight({double width = 0.8, double alpha = 1.0, BloomStroke style = BloomStroke.glassStrokeMiddleLight})
const

Properties

alpha double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style BloomStroke
final
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited