LightPosition class

光源的 3D 位置(归一化 UV)。对应 Kotlin LightPosition

着色器把 (x-0.5, y-0.7, z) 归一化为方向;x/y0,1 为相对高光边界的 UV 位置,(0.5,0.7) 为参考原点(放这里无贡献);z 有符号深度,负值置于表面之后。

Annotations

Constructors

LightPosition(double x, double y, double z)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final
z double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited