MiuixBasicComponentColors class

BasicComponent 颜色配置。对应 Kotlin BasicComponentColors

Annotations

Constructors

MiuixBasicComponentColors({required Color color, required Color disabledColor})
const

Properties

color Color
final
disabledColor Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(bool enabled) Color
根据 enabled 返回当前颜色。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited