MiuixBasicComponentDefaults class

BasicComponent 默认值。对应 Kotlin BasicComponentDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

summaryColor(BuildContext context) MiuixBasicComponentColors
摘要默认颜色。
titleColor(BuildContext context) MiuixBasicComponentColors
标题默认颜色。

Constants

insideMargin → const EdgeInsets
组件四周默认内边距,均为 16 逻辑像素。