MiuixCard class

Miuix 风格的 Card。对应 Kotlin Card

使用 squircle 圆角,向下传递 MiuixContentColor。 传入 onPressed 时可点击,并可选 sink/tilt 按压反馈。

Inheritance

Constructors

MiuixCard({Key? key, double cornerRadius = MiuixCardDefaults.cornerRadius, EdgeInsetsGeometry insideMargin = MiuixCardDefaults.insideMargin, MiuixCardColors? colors, VoidCallback? onPressed, VoidCallback? onLongPress, MiuixPressFeedbackType feedbackType = MiuixPressFeedbackType.none, Widget? child})
const

Properties

child Widget?
final
colors MiuixCardColors?
颜色配置,默认取 MiuixCardDefaults.defaultColors
final
cornerRadius double
圆角半径。
final
feedbackType MiuixPressFeedbackType
按压反馈类型(sink/tilt)。
final
hashCode int
The hash code for this object.
no setterinherited
insideMargin EdgeInsetsGeometry
内边距。
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLongPress VoidCallback?
长按回调。
final
onPressed VoidCallback?
点击回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited