MiuixCardDefaults class

Card 默认值。对应 Kotlin CardDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultColors(BuildContext context) MiuixCardColors
默认颜色:surfaceContainer / onSurfaceContainer。

Constants

cornerRadius → const double
默认圆角半径。
insideMargin → const EdgeInsets
默认内边距。