MiuixColorPicker class

Miuix 风格、支持多色彩空间的取色器。对应 Kotlin ColorPicker

根据 colorSpace 分派到对应的子取色器。

Inheritance

Constructors

MiuixColorPicker({Key? key, required Color color, required ValueChanged<Color> onColorChanged, bool showPreview = true, MiuixSliderHapticEffect hapticEffect = MiuixSliderDefaults.defaultHapticEffect, MiuixColorSpace colorSpace = MiuixColorSpace.hsv})
const

Properties

color Color
当前颜色。
final
colorSpace MiuixColorSpace
使用的色彩空间,默认 MiuixColorSpace.hsv
final
hapticEffect MiuixSliderHapticEffect
滑块的触感反馈类型,默认与 Slider 一致(边缘反馈)。
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onColorChanged ValueChanged<Color>
颜色变化回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPreview bool
是否显示所选颜色的预览条。
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited