MiuixColorSpace enum
取色器使用的色彩空间。对应 Kotlin ColorSpace。
Values
- hsv → const MiuixColorSpace
-
传统 HSV。
- okhsv → const MiuixColorSpace
-
基于 OkLab 的 OkHSV,感知均匀性更好。
- oklab → const MiuixColorSpace
-
OkLab(明度 + 绿红轴 + 蓝黄轴)。
- oklch → const MiuixColorSpace
-
OkLCH(明度 + 色度 + 色相)。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MiuixColorSpace> - A constant List of the values in this enum, in order of their declaration.