MiuixDatePickerColors class

DatePicker 颜色配置。对应 HyperOS 日历配色 token。

Annotations

Constructors

MiuixDatePickerColors({required Color backgroundColor, required Color headerColor, required Color weekdayColor, required Color weekendWeekdayColor, required Color dayColor, required Color weekendDayColor, required Color outOfMonthDayColor, required Color selectedDayColor, required Color selectedDayTextColor, required Color todayBorderColor, required Color disabledDayColor, required Color navigationIconColor})
const

Properties

backgroundColor Color
整个日历卡片背景色。
final
dayColor Color
当月日期数字默认色。
final
disabledDayColor Color
禁用日期数字色。
final
hashCode int
The hash code for this object.
no setterinherited
headerColor Color
顶部"2026年7月"标题色。
final
月份切换箭头颜色。
final
outOfMonthDayColor Color
非当月日期数字色(前后月填充格)。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDayColor Color
选中态背景色。
final
selectedDayTextColor Color
选中态文字色。
final
todayBorderColor Color
"今天"格子的边框色。
final
weekdayColor Color
工作日周名颜色(一/二/三/四/五)。
final
weekendDayColor Color
当月周末数字色。
final
weekendWeekdayColor Color
周末周名颜色(六/日)。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultColors(BuildContext context) MiuixDatePickerColors
默认配色:与 HyperOS 浅/深色主题一致。