MiuixDatePickerDefaults class

DatePicker 默认尺寸。对应 HyperOS 视觉规范。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cellCornerRadius → const double
日期单元格圆角(squircle)。
cellHeight → const double
日期单元格高度。
cornerRadius → const double
卡片圆角,与 MiuixCard 一致。
headerHeight → const double
顶部月份切换器高度。
insideMargin → const EdgeInsets
卡片内边距。
monthSwitchDuration → const Duration
月份切换动画时长。
月份切换按钮尺寸。
selectionDuration → const Duration
选中态颜色过渡时长。
weekdayRowHeight → const double
周名行高度。