MiuixDialogDefaults class
Miuix 对话框默认值。对应 Kotlin DialogDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
backgroundColor(
BuildContext context) → Color -
summaryColor(
BuildContext context) → Color -
titleColor(
BuildContext context) → Color
Constants
- cornerRadius → const double
- insideMargin → const Size
- maxWidth → const double
- outsideMargin → const Size