MiuixDialogLayout class

在当前 Scope 中注册一个对话框;自身不绘制任何内容。

Inheritance

Constructors

MiuixDialogLayout({Key? key, required MiuixPopupController controller, required WidgetBuilder? content, MiuixPopupTransition? enterTransition, MiuixPopupTransition? exitTransition, bool enableWindowDim = true, bool enableAutoLargeScreen = true, MiuixPopupTransition? dimEnterTransition, MiuixPopupTransition? dimExitTransition, ValueListenable<double>? dimAlpha, VoidCallback? onDismissFinished, bool renderInRoot = true})
const

Properties

content WidgetBuilder?
final
controller MiuixPopupController
final
dimAlpha ValueListenable<double>?
final
dimEnterTransition MiuixPopupTransition?
final
dimExitTransition MiuixPopupTransition?
final
enableAutoLargeScreen bool
final
enableWindowDim bool
final
enterTransition MiuixPopupTransition?
final
exitTransition MiuixPopupTransition?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDismissFinished VoidCallback?
final
renderInRoot bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MiuixDialogLayout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited