MiuixDividerDefaults class

Divider 默认值。对应 Kotlin DividerDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dividerColor(BuildContext context) Color
默认颜色,取自 MiuixTheme.colors.dividerLine

Constants

thickness → const double
默认厚度 0.75dp。