MiuixDropdownDefaults class
下拉行的默认尺寸、间距与颜色。对应 Kotlin DropdownDefaults。
所有 dp 值直接作为逻辑像素使用。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dialogDropdownColors(
BuildContext context, {Color? contentColor, Color? summaryColor, Color? containerColor, Color? selectedContentColor, Color? selectedSummaryColor, Color? selectedContainerColor, Color? selectedIndicatorColor}) → MiuixDropdownColors -
对话框模式的默认颜色。对应 Kotlin
DropdownDefaults.dialogDropdownColors()。 -
dropdownColors(
BuildContext context, {Color? contentColor, Color? summaryColor, Color? containerColor, Color? selectedContentColor, Color? selectedSummaryColor, Color? selectedContainerColor, Color? selectedIndicatorColor}) → MiuixDropdownColors -
弹窗模式的默认颜色。对应 Kotlin
DropdownDefaults.dropdownColors()。
Constants
- arrowSize → const Size
- MiuixDropdownArrowEndAction 中上下箭头的尺寸(宽 x 高)。
- checkIconSize → const double
- 选中项尾部勾号的尺寸。
- checkIconStartPadding → const double
- 标题/摘要块与尾部勾号之间的间距。
- chevronSize → const Size
- 拥有子菜单的行的尾部箭头尺寸(宽 x 高)。
- dialogHorizontalPadding → const double
- 对话框模式下每行的水平内边距。
- firstLastVerticalPadding → const double
- 弹窗模式下首/末行的上/下内边距。
- iconEndPadding → const double
- 前置图标单元格与标题文本之间的间距。
- iconMinSize → const double
- 前置图标单元格的最小尺寸。
- insideHorizontalPadding → const double
- 弹窗模式下每行的水平内边距。
- maxItemTextWidth → const double
- 弹窗模式下内部图标/文本行的最大宽度。
- middleVerticalPadding → const double
- 弹窗模式下中间行、以及对话框模式下所有行的上/下内边距。
- minHeight → const double
- 对话框模式下的最小行高。
- minWidth → const double
- 对话框模式下的最小行宽。