MiuixDropdownEntriesDialogItems class

在对话框容器内渲染 MiuixDropdownEntry 分组列表(ListView 子项列表)。 对应 Kotlin LazyListScope.dropdownEntriesDialogItems

对话框模式使用统一的垂直内边距,不传播弹窗全局 first/last。分组之间同样插入 1.5dp 分隔线。返回的 Widget 列表可直接作为 ListView / Column 的 children。

Inheritance

Constructors

MiuixDropdownEntriesDialogItems({Key? key, required List<MiuixDropdownEntry> entries, required MiuixDropdownColors dropdownColors, required void onItemClick(int entryIdx, int itemIdx)})
const

Properties

final
entries List<MiuixDropdownEntry>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onItemClick → void Function(int entryIdx, int itemIdx)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited