MiuixFloatingActionButtonDefaults class

FloatingActionButton 默认值。对应 Kotlin FloatingActionButtonDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

minHeight → const double
默认最小高度。
minWidth → const double
默认最小宽度。
shadowElevation → const double
默认阴影高度。
shape → const ShapeBorder
默认形状。对应 Kotlin CircleShape(正方形 bounds 下为正圆,矩形下为胶囊)。