MiuixFloatingNavigationBarDefaults class
悬浮导航栏默认值。对应 Kotlin FloatingNavigationBarDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColors(
BuildContext context) → MiuixNavigationBarColors - 从当前 Miuix 主题创建导航栏默认颜色。
Constants
- cornerRadius → const double
-
与 Kotlin
FloatingToolbarDefaults.CornerRadius一致。 - horizontalOutSidePadding → const double
- horizontalPadding → const double
- iconPadding → const double
- iconSize → const double
- itemSpacing → const double
- selectedPressedAlpha → const double
- shadowElevation → const double
- unselectedAlpha → const double
- unselectedPressedAlpha → const double