MiuixGlass class

对应 Kotlin Modifier.glass。必须放在 backdrop 捕获子树之外,防止反馈采样。

无 backdrop 或 shader 不可用时保留纯色轮廓、阴影及可绘制的高光,不伪装成折射效果。 shading 为 false 时使用 OS4 栏/菜单的 MaterialToken,而非仿生折射 GlassToken。

Inheritance
Implementers

Constructors

MiuixGlass({Key? key, MiuixBackdrop? backdrop, MiuixGlassStyle? style, MiuixGlassMaterial? material, MiuixGlassMaterial? underlayMaterial, MiuixGlassShape shape = const MiuixGlassShape(), double alpha = 1, Color? tint, Color? fill, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow, bool shading = true, bool enabled = true, required Widget child})
const

Properties

alpha → double
final
backdrop → MiuixBackdrop?
final
child → Widget
final
enabled → bool
final
fill → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
material → MiuixGlassMaterial?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shading → bool
final
shadow → MiuixGlassShadow?
final
shape → MiuixGlassShape
final
stroke → MiuixGlassStroke?
final
style → MiuixGlassStyle?
final
tint → Color?
final
underlayMaterial → MiuixGlassMaterial?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MiuixGlass>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited