MiuixGlassDialog class

对应 Kotlin GlassDialog。居中玻璃对话框,安全区和软键盘会约束内容可用高度。

Inheritance

Constructors

MiuixGlassDialog({Key? key, required bool visible, required VoidCallback onDismissRequest, required Widget child, MiuixBackdrop? backdrop, double? scrimAlpha, VoidCallback? onDismissFinished, double cornerRadius = 28, MiuixGlassPopupSizing sizing = const MiuixGlassPopupSizing(maxWidth: 420, maxHeight: 100000, safeMargin: 24), MiuixGlassPopupVisuals visuals = const MiuixGlassPopupVisuals(shadow: MiuixGlassShadows.extraHigh, showStroke: false), EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 22, vertical: 20)})
const

Properties

anchor → MiuixGlassPopupAnchor?
finalinherited
anchorBounds → Rect?
finalinherited
anchorContent → Widget?
finalinherited
backdrop → MiuixBackdrop?
finalinherited
child → Widget
finalinherited
contentPadding → EdgeInsets
finalinherited
cornerRadius → double
finalinherited
gap → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maskColor → Color?
finalinherited
materialAnchor → MiuixGlassPopupAnchor?
finalinherited
motion → MiuixGlassPopupMotion
finalinherited
onDismissFinished → VoidCallback?
finalinherited
onDismissRequest → VoidCallback
finalinherited
onMeasured → ValueChanged<Size>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrimAlpha → double?
finalinherited
show → bool
finalinherited
simplified → bool
finalinherited
sizing → MiuixGlassPopupSizing
finalinherited
stacked → bool
finalinherited
visuals → MiuixGlassPopupVisuals
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited