MiuixGlassEdge class

对应 Kotlin GlassEdge。

Annotations

Constructors

MiuixGlassEdge({required double width, required double pow, required double thickness, required double reflectOffset})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pow → double
final
reflectOffset → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double
final
width → double
final

Methods

copyWith({double? width, double? pow, double? thickness, double? reflectOffset}) → MiuixGlassEdge
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited