MiuixGlassIconButton class

对应 Kotlin GlassIconButton;自动继承 OS4 顶栏材质与同步的显隐进度。

Inheritance

Constructors

MiuixGlassIconButton({Key? key, required VoidCallback? onPressed, required Widget child, MiuixBackdrop? backdrop, MiuixGlassPopupAnchor? anchor, MiuixGlassStyle? style, double? size, MiuixGlassShape? shape, double surfaceAlpha = 1, Color? fill, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow = MiuixGlassShadows.regular, String? semanticLabel, String? tooltip})
const

Properties

anchor → MiuixGlassPopupAnchor?
final
backdrop → MiuixBackdrop?
final
child → Widget
final
fill → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
shadow → MiuixGlassShadow?
final
shape → MiuixGlassShape?
final
size → double?
final
stroke → MiuixGlassStroke?
final
style → MiuixGlassStyle?
final
surfaceAlpha → double
final
tooltip → String?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MiuixGlassIconButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited