MiuixGlassInner class

对应 Kotlin GlassInner。

Annotations

Constructors

MiuixGlassInner({required double bottom, required Color tint, required double tintStrength, required double colorWhite, required double colorMix, required double colorPow, required double alpha})
const

Properties

alpha → double
final
bottom → double
final
colorMix → double
final
colorPow → double
final
colorWhite → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tint → Color
final
tintStrength → double
final

Methods

copyWith({double? bottom, Color? tint, double? tintStrength, double? colorWhite, double? colorMix, double? colorPow, double? alpha}) → MiuixGlassInner
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited