MiuixGlassNavigationBar class

对应 Kotlin GlassNavigationBar,支持跨目的地拖动、可中断回弹和自适应双行标签。

Inheritance

Constructors

MiuixGlassNavigationBar({Key? key, required List<MiuixGlassNavigationItem> items, required int selectedIndex, required ValueChanged<int> onSelect, MiuixBackdrop? backdrop, MiuixGlassStyle? style, MiuixGlassMaterial? material, double alpha = 1, bool visible = true, double height = 54, MiuixGlassShape? shape, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow = MiuixGlassShadows.floating, Color? indicatorColor, Color? indicatorPressedColor, Color? selectedColor, Color? unselectedColor})
const

Properties

alpha → double
final
backdrop → MiuixBackdrop?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
indicatorColor → Color?
final
indicatorPressedColor → Color?
final
items → List<MiuixGlassNavigationItem>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
material → MiuixGlassMaterial?
final
onSelect → ValueChanged<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
final
selectedIndex → int
final
shadow → MiuixGlassShadow?
final
shape → MiuixGlassShape?
final
stroke → MiuixGlassStroke?
final
style → MiuixGlassStyle?
final
unselectedColor → Color?
final
visible → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MiuixGlassNavigationBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited