MiuixGlassNavigationBarDefaults class
对应 Kotlin GlassNavigationBarDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- contentPaddingHorizontal → const double
- contentPaddingVertical → const double
- height → const double
- iconSize → const double
- indicatorOverhang → const double
- indicatorPaddingVertical → const double
- labelSize → const double
- largeLabelSize → const double
- pressedAlpha → const double