MiuixGlassNavigationDragTarget class

对应上游 NavigationDragTarget。跟手拉伸上限为 60 个物理像素,不能当作 60dp。

Annotations

Constructors

MiuixGlassNavigationDragTarget(double left, double right, bool following, bool movingRight)
const

Properties

following → bool
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
final
movingRight → bool
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited