MiuixGlassNavigationItem class

对应 Kotlin GlassNavigationItem。

Annotations

Constructors

MiuixGlassNavigationItem({required Widget icon, String? label, String? contentDescription, bool isAction = false})
const

Properties

contentDescription → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
final
isAction → bool
final
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited