MiuixGlassPopupDefaults class
对应 Kotlin GlassPopupDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- contentPaddingVertical → const double
- cornerRadius → const double
- dividerPaddingHorizontal → const double
- dividerPaddingVertical → const double
- dividerThickness → const double
- itemIconGap → const double
- itemIconSize → const double
- itemMinHeight → const double
- itemPaddingHorizontal → const double
- itemPaddingVertical → const double
- itemPressInset → const double
- itemPressRadius → const double
- maxHeight → const double
- maxWidth → const double
- minWidth → const double
- safeMargin → const double