MiuixGlassPopupFrame class

对应 Kotlin GlassPopupFrame。

Annotations

Constructors

MiuixGlassPopupFrame(Rect rect, double cornerRadius)
const

Properties

cornerRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
rect → Rect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited