MiuixGlassPopupSizing class

对应 Kotlin GlassPopupSizing。

Annotations

Constructors

MiuixGlassPopupSizing({double minWidth = 200, double maxWidth = 288, double maxHeight = 416, double safeMargin = 12})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxHeight → double
final
maxWidth → double
final
minWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMargin → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited