MiuixGlassRefract class

对应 Kotlin GlassRefract。

Annotations

Constructors

MiuixGlassRefract({required double ior})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ior → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? ior}) → MiuixGlassRefract
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited