MiuixGlassSegmentedTabRow class

对应 Kotlin GlassSegmentedTabRow:共用轨道,选中指示器连续移动。

Inheritance

Constructors

MiuixGlassSegmentedTabRow({Key? key, required List<String> tabs, required int selectedIndex, required ValueChanged<int>? onSelect, MiuixBackdrop? backdrop, MiuixGlassStyle? style, MiuixGlassMaterial? material, double alpha = 1, double surfaceAlpha = 1, double height = 40, Color? trackColor, Color? indicatorColor, Color? selectedContentColor, Color? contentColor, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow = MiuixGlassShadows.floating})
const

Properties

alpha → double
final
backdrop → MiuixBackdrop?
final
contentColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
indicatorColor → Color?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
material → MiuixGlassMaterial?
final
onSelect → ValueChanged<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedContentColor → Color?
final
selectedIndex → int
final
shadow → MiuixGlassShadow?
final
stroke → MiuixGlassStroke?
final
style → MiuixGlassStyle?
final
surfaceAlpha → double
final
tabs → List<String>
final
trackColor → Color?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited