MiuixGlassShadow class

对应 Kotlin GlassShadow。位移和 radius 为源端像素,绘制时除以 sourceDensity=3。

Annotations

Constructors

MiuixGlassShadow({Color color = const Color.from(alpha: .05, red: 0, green: 0, blue: 0), double offsetX = 0, double offsetY = 0, double radius = 64, double dispersion = .5})
const

Properties

color → Color
final
dispersion → double
final
hashCode → int
The hash code for this object.
no setterinherited
offsetX → double
final
offsetY → double
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited