MiuixGlassStyle class

对应 Kotlin GlassStyle。

Annotations

Constructors

MiuixGlassStyle({required MiuixGlassBlend blend, required MiuixGlassInner inner, required MiuixGlassEdge edge, required MiuixGlassReflect reflect, required MiuixGlassLight light, required MiuixGlassRefract refract, required MiuixGlassBackground background, required MiuixGlassBlur blur})
const

Properties

background → MiuixGlassBackground
final
blend → MiuixGlassBlend
final
blur → MiuixGlassBlur
final
edge → MiuixGlassEdge
final
hashCode → int
The hash code for this object.
no setterinherited
inner → MiuixGlassInner
final
light → MiuixGlassLight
final
reflect → MiuixGlassReflect
final
refract → MiuixGlassRefract
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MiuixGlassBlend? blend, MiuixGlassInner? inner, MiuixGlassEdge? edge, MiuixGlassReflect? reflect, MiuixGlassLight? light, MiuixGlassRefract? refract, MiuixGlassBackground? background, MiuixGlassBlur? blur}) → MiuixGlassStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited