MiuixGlassStyles class

对应 Kotlin GlassStyles:全部 35 组源端材质参数。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

forTheme(bool isDark) → MiuixGlassStyle

Constants

bionicMediumDemiboldMotion → const MiuixGlassStyle
bionicMediumNormal → const MiuixGlassStyle
bionicMediumNormalMotion → const MiuixGlassStyle
bionicMediumRegular → const MiuixGlassStyle
bionicMediumSemiboldMotion → const MiuixGlassStyle
bionicMediumThin → const MiuixGlassStyle
commonLargeDemibold → const MiuixGlassStyle
commonLargeRegular → const MiuixGlassStyle
commonMediumBoldDark → const MiuixGlassStyle
commonMediumBoldLight → const MiuixGlassStyle
commonMediumBoldLow → const MiuixGlassStyle
commonMediumRegularDark → const MiuixGlassStyle
commonMediumRegularHighLight → const MiuixGlassStyle
commonMediumRegularLowLight → const MiuixGlassStyle
commonMediumThinHigh → const MiuixGlassStyle
commonMediumThinLow → const MiuixGlassStyle
commonSmallBold → const MiuixGlassStyle
commonSmallNormal → const MiuixGlassStyle
commonSmallRegular → const MiuixGlassStyle
commonSmallSemibold → const MiuixGlassStyle
commonSmallThin → const MiuixGlassStyle
tintBlackDemibold → const MiuixGlassStyle
tintBlackHeavy → const MiuixGlassStyle
tintBlackNormal → const MiuixGlassStyle
tintBlackRegular → const MiuixGlassStyle
tintBlackThin → const MiuixGlassStyle
tintBlue → const MiuixGlassStyle
tintBlueMotion → const MiuixGlassStyle
tintBlueNormal → const MiuixGlassStyle
tintBrown → const MiuixGlassStyle
tintGreenMotion → const MiuixGlassStyle
tintOrange → const MiuixGlassStyle
tintPurple → const MiuixGlassStyle
tintRedMotion → const MiuixGlassStyle
tintYellow → const MiuixGlassStyle
values → const Map<String, MiuixGlassStyle>