MiuixGlassTabRow class

对应 Kotlin GlassTabRow:每个标签是独立胶囊,无跨标签滑动指示器。

Inheritance

Constructors

MiuixGlassTabRow({Key? key, required List<String> tabs, required int selectedIndex, required ValueChanged<int>? onSelect, MiuixBackdrop? backdrop, MiuixGlassStyle? style, MiuixGlassMaterial? material, MiuixGlassTabColors? colors, double alpha = 1, double surfaceAlpha = 1, double height = 40, double tabGap = 12, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow = MiuixGlassShadows.floating})
const

Properties

alpha → double
final
backdrop → MiuixBackdrop?
final
colors → MiuixGlassTabColors?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
material → MiuixGlassMaterial?
final
onSelect → ValueChanged<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex → int
final
shadow → MiuixGlassShadow?
final
stroke → MiuixGlassStroke?
final
style → MiuixGlassStyle?
final
surfaceAlpha → double
final
tabGap → double
final
tabs → List<String>
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited