MiuixGlassTabRowDefaults class

对应 Kotlin GlassTabRowDefaults。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

height → const double
neutralHeight → const double
tabGap → const double
tabPaddingHorizontal → const double
tabPaddingVertical → const double