MiuixGlassTopAppBarDefaults class

对应 Kotlin GlassTopAppBarDefaults。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bandBlurMask() → LinearGradient
模糊层自身的淡出遮罩(白色=保留,透明=擦除):让模糊在 band 下缘附近 平滑消失,避免矩形硬边。
bandBrush(Color color) → LinearGradient
band 默认色调渐变:半透版本——下方有真实高斯模糊垫底,顶部不再需要 不透明色块(旧版顶部 ~45% 为纯 surface 色,观感是不透明实带,与原生 HyperOS 4「整块高斯模糊 + 半透色调」不符)。如需旧版实色带,给 MiuixGlassTopAppBar.bandBrush 传不透明渐变即可。
bandMaterial(bool isDark, double blurRadius) → MiuixGlassMaterial
nestedMaterial(bool isDark) → MiuixGlassMaterial

Constants

bandOverhang → const double
buttonSize → const double
horizontalPadding → const double
largeTitleBlurRadius → const double
nestedBlurDark → const double
顶栏遮罩的模糊与子控件自身 20dp 遮罩叠加后的等效模糊(源端 NESTED_BLUR)。
nestedBlurLight → const double
顶栏遮罩的模糊与子控件自身 20dp 遮罩叠加后的等效模糊(源端 NESTED_BLUR)。
pressedContentAlpha → const double