MiuixGlassTransformPopup class

对应 Kotlin GlassTransformPopup。从按钮连续变形成菜单;anchorContent 传入无 GlobalKey 的图标副本。 保持组件挂载并切换 show,让退出动画完成后自动清除弹层和返回记录。

Inheritance

Constructors

MiuixGlassTransformPopup({Key? key, required bool show, required VoidCallback onDismissRequest, required Widget child, required MiuixGlassPopupAnchor? anchor, required Widget? anchorContent, bool simplified = false, bool stacked = false, Color? maskColor, double gap = 0, MiuixBackdrop? backdrop, MiuixGlassPopupSizing sizing = const MiuixGlassPopupSizing(), MiuixGlassPopupVisuals visuals = const MiuixGlassPopupVisuals(), double cornerRadius = 24, EdgeInsets contentPadding = const EdgeInsets.symmetric(vertical: 8), VoidCallback? onDismissFinished, ValueChanged<Size>? onMeasured})
const

Properties

anchor → MiuixGlassPopupAnchor?
finalinherited
anchorBounds → Rect?
finalinherited
anchorContent → Widget?
finalinherited
backdrop → MiuixBackdrop?
finalinherited
child → Widget
finalinherited
contentPadding → EdgeInsets
finalinherited
cornerRadius → double
finalinherited
gap → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maskColor → Color?
finalinherited
materialAnchor → MiuixGlassPopupAnchor?
finalinherited
motion → MiuixGlassPopupMotion
finalinherited
onDismissFinished → VoidCallback?
finalinherited
onDismissRequest → VoidCallback
finalinherited
onMeasured → ValueChanged<Size>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrimAlpha → double?
finalinherited
show → bool
finalinherited
simplified → bool
finalinherited
sizing → MiuixGlassPopupSizing
finalinherited
stacked → bool
finalinherited
visuals → MiuixGlassPopupVisuals
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited