MiuixHapticFeedbackType enum
触觉反馈类型。对应 Kotlin HapticFeedbackType。
默认 textHandleMove:与 Android TextHandleMove 一样是轻微的「咔哒」触感,
映射到 Flutter 的 HapticFeedback.selectionClick。
Values
- textHandleMove → const MiuixHapticFeedbackType
-
轻微选择反馈(默认)。对应 Android
TextHandleMove。 - lightImpact → const MiuixHapticFeedbackType
-
轻碰。
- mediumImpact → const MiuixHapticFeedbackType
-
中等碰撞。
- heavyImpact → const MiuixHapticFeedbackType
-
重碰撞。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MiuixHapticFeedbackType> - A constant List of the values in this enum, in order of their declaration.