MiuixIconButton class

Miuix 风格的图标按钮。对应 Kotlin IconButton。

Inheritance

Constructors

MiuixIconButton({Key? key, required VoidCallback? onPressed, required Widget child, bool enabled = true, Color? backgroundColor, double cornerRadius = MiuixIconButtonDefaults.cornerRadius, double minHeight = MiuixIconButtonDefaults.minHeight, double minWidth = MiuixIconButtonDefaults.minWidth, bool holdDownState = false})
const

Properties

backgroundColor → Color?
背景色,null 表示透明。
final
child → Widget
final
cornerRadius → double
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
holdDownState → bool
强制按住视觉态。对应 Kotlin holdDownState,下拉菜单展开期间置 true。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minHeight → double
final
minWidth → double
final
onPressed → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited