MiuixIconWeight enum
扩展图标的字重。对应 Kotlin MiuixIcons.{Light,Normal,Regular,Medium,Demibold}。
Values
- light → const MiuixIconWeight
- normal → const MiuixIconWeight
- regular → const MiuixIconWeight
- medium → const MiuixIconWeight
- demibold → const MiuixIconWeight
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MiuixIconWeight> - A constant List of the values in this enum, in order of their declaration.