MiuixIcons class

Miuix 内置图标集合入口。对应 Kotlin object MiuixIcons

公开 basic(对应 MiuixIcons.Basic)与 extended(对应 MiuixIcons.Extended, 156 个图标 × 5 种字重)。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

basic → const MiuixBasicIcons
组件内部使用的基础矢量图标。对应 Kotlin MiuixIcons.Basic
extended → const MiuixExtendedIcons
扩展图标(156 个 × 5 字重)。对应 Kotlin MiuixIcons.Extended