MiuixInputField class

对应 Kotlin InputField 的 Miuix 搜索输入框。

Inheritance

Constructors

MiuixInputField({Key? key, required String query, required ValueChanged<String> onQueryChange, required ValueChanged<String> onSearch, required bool expanded, required ValueChanged<bool> onExpandedChange, String label = '', bool enabled = true, TextStyle? textStyle, Color? color, Widget? leadingIcon, Widget? trailingIcon, FocusNode? focusNode})
const

Properties

color Color?
final
enabled bool
final
expanded bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
leadingIcon Widget?
final
onExpandedChange ValueChanged<bool>
final
onQueryChange ValueChanged<String>
final
onSearch ValueChanged<String>
final
query String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final
trailingIcon Widget?
自定义尾图标;null 时使用带淡入淡出的默认清除按钮。
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MiuixInputField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited