MiuixLinearProgressIndicator class

Miuix 风格线性进度指示器。对应 Kotlin LinearProgressIndicator。

progress 位于 0 到 1;为 null 时显示 1250ms 线性循环动画。 即使进度为 0,前景仍保留一个高度宽的圆头胶囊。

Inheritance

Constructors

MiuixLinearProgressIndicator({Key? key, double? progress, MiuixProgressIndicatorColors? colors, double height = MiuixProgressIndicatorDefaults.defaultLinearHeight})
const

Properties

colors → MiuixProgressIndicatorColors?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
progress → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MiuixLinearProgressIndicator>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited