MiuixMotion class

Miuix 常用动效曲线集合,按 HyperOS 交互习惯分类。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bouncySpring SpringDescription
弹性切换 spring(轻微欠阻尼,有自然回弹)。
no setter
pressSpring SpringDescription
通用按压/状态切换的 spring(临界阻尼,无过冲,快速响应)。
no setter

Constants

sinOut → const Curve
正弦缓出,用于柔和的位移/缩放。
standardAccelerate → const Curve
标准缓入,用于退场/消失。
standardDecelerate → const Curve
标准缓出,用于进场/出现。