MiuixNavigationBarColors class

导航栏颜色。集中保存普通与悬浮导航栏使用的主题色。

Annotations

Constructors

MiuixNavigationBarColors({required Color background, required Color floatingBackground, required Color content, required Color divider})
const

Properties

background Color
普通导航栏背景色。
final
content Color
图标和标签的基础颜色;状态透明度在此颜色之上计算。
final
divider Color
分隔线和悬浮描边颜色。
final
floatingBackground Color
悬浮导航栏背景色。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited