MiuixNavigationBarDisplayMode enum

导航项显示模式。对应 Kotlin NavigationBarDisplayMode

Inheritance
Available extensions

Values

iconAndText → const MiuixNavigationBarDisplayMode

始终显示图标和文本。

iconOnly → const MiuixNavigationBarDisplayMode

仅显示图标。

iconWithSelectedLabel → const MiuixNavigationBarDisplayMode

始终显示图标,仅为选中项显示文本。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MiuixNavigationBarDisplayMode>
A constant List of the values in this enum, in order of their declaration.