MiuixNavigationBarItem class

普通导航项。对应 Kotlin NavigationBarItem

iconlabelWidget 是槽位;未提供 labelWidget 时使用 label 构造 文本。整个导航项只暴露一个选项卡语义节点,装饰性图标和可见文本不会被 屏幕阅读器重复朗读。

Inheritance

Constructors

MiuixNavigationBarItem({Key? key, required bool selected, required VoidCallback? onPressed, required Widget icon, required String label, Widget? labelWidget, bool enabled = true, Widget? badge})
const

Properties

badge Widget?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
labelWidget Widget?
final
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MiuixNavigationBarItem>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited