MiuixNavigationItem class

导航项数据。对应 Kotlin NavigationItem

Annotations

Constructors

MiuixNavigationItem({required String label, required Widget icon, Widget? badge})
const

Properties

badge Widget?
可选 badge 槽,锚定在图标的顶部末端。
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
图标槽;组件会通过 IconTheme 提供尺寸和状态色。
final
label String
可访问性标签及默认可见标签文本。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited