MiuixNavigationRailState class

控制 MiuixNavigationRail 展开与折叠的状态对象。

Flutter 没有 Compose rememberSaveable 对应的进程恢复机制;如需跨进程 保存,请由业务层持久化 currentValue 并作为 initialValue 恢复。

Inheritance

Constructors

MiuixNavigationRailState({MiuixNavigationRailValue initialValue = MiuixNavigationRailValue.collapsed})

Properties

currentValue MiuixNavigationRailValue
当前展开状态。
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isExpanded bool
当前是否展开。
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
collapse() → void
折叠导航栏。
dispose() → void
Discards any resources used by the object.
inherited
expand() → void
展开导航栏。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toggle() → void
在展开与折叠之间切换。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited