MiuixNumberPicker class

Miuix 风格的垂直数字选择器。对应 Kotlin NumberPicker。

Inheritance

Constructors

MiuixNumberPicker({Key? key, required int value, required ValueChanged<int>? onValueChanged, bool enabled = true, int min = 0, int max = 10, String label(int)?, int visibleItemCount = 5, bool wrapAround = false, MiuixNumberPickerColors? colors, TextStyle? textStyle, double itemHeight = MiuixNumberPickerDefaults.itemHeight})
const

Properties

colors → MiuixNumberPickerColors?
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
itemHeight → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String Function(int)?
final
max → int
final
min → int
final
onValueChanged → ValueChanged<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
final
value → int
final
visibleItemCount → int
final
wrapAround → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MiuixNumberPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited