MiuixPopupController class
控制一个对话框或普通弹窗的显示状态。
控制器可在布局组件重建时保持不变,也可直接监听 visibleListenable。
- Inheritance
-
- Object
- ChangeNotifier
- MiuixPopupController
- Implemented types
Constructors
- MiuixPopupController({bool visible = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → bool
-
ValueListenable 的当前值,等同于 visible。
no setteroverride
- visible ↔ bool
-
getter/setter pair
-
visibleListenable
→ ValueListenable<
bool> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dismiss(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
show(
) → void -
toggle(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited