MiuixPopupDefaults class
Kotlin 默认过渡的 Flutter 等价定义。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- dialogDimEnter → MiuixPopupTransition
-
对话框遮罩进入:300ms、减速曲线。
final
- dialogDimExit → MiuixPopupTransition
-
对话框遮罩退出:250ms、减速曲线。
final
- largeDialogEnter → MiuixPopupTransition
-
大屏对话框内容以淡入和 0.8→1 缩放弹簧进入。
final
- largeDialogExit → MiuixPopupTransition
-
大屏对话框内容淡出并缩放至 0.8。
final
- popupDimEnter → MiuixPopupTransition
-
普通弹窗遮罩进入:300ms、正弦缓出。
final
- popupDimExit → MiuixPopupTransition
-
普通弹窗遮罩退出:150ms、正弦缓出。
final
- popupEnter → MiuixPopupTransition
-
普通弹窗内容进入:200ms 淡入。
final
- popupExit → MiuixPopupTransition
-
普通弹窗内容退出:150ms 淡出。
final
- smallDialogEnter → MiuixPopupTransition
-
小屏对话框从自身高度的下方弹簧滑入。
final
- smallDialogExit → MiuixPopupTransition
-
小屏对话框向自身高度的下方滑出。
final