MiuixPopupLayoutPosition class

弹窗位于锚点的哪一侧,以及贴近锚点的哪条横向边。

Annotations

Constructors

MiuixPopupLayoutPosition({required bool showBelow, required bool showAbove, required bool isRightAligned})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isRightAligned bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAbove bool
final
showBelow bool
final
showMiddle bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited