MiuixPressFeedbackType enum

按压视觉反馈类型。对应 Kotlin PressFeedbackType

Inheritance
Available extensions

Values

none → const MiuixPressFeedbackType

无反馈(仅按压遮罩)。

sink → const MiuixPressFeedbackType

按下时轻微下沉缩放。

tilt → const MiuixPressFeedbackType

按下时根据触点位置倾斜(3D)。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MiuixPressFeedbackType>
A constant List of the values in this enum, in order of their declaration.