MiuixProgressIndicatorDefaults class
进度指示器默认值。对应 Kotlin ProgressIndicatorDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColors(
BuildContext context) → MiuixProgressIndicatorColors - 返回线性与圆形进度指示器的默认颜色。
Constants
- defaultCircularSize → const double
- defaultCircularStrokeWidth → const double
- defaultInfiniteOrbitingDotSize → const double
- defaultInfiniteSize → const double
- defaultInfiniteStrokeWidth → const double
- defaultLinearHeight → const double