MiuixPullToRefreshController class

保存下拉距离、进度和刷新视觉状态的控制器。

refreshThreshold 表示完整阻尼拖拽范围中触发刷新的比例,取值会限制在 0 到 1。刷新业务状态仍应由 MiuixPullToRefresh.isRefreshing 提升管理。

Inheritance

Constructors

MiuixPullToRefreshController({double refreshThreshold = MiuixPullToRefreshDefaults.refreshThreshold})

Properties

dragOffset double
当前阻尼后的下拉距离(逻辑像素)。
no setter
fullDragProgress double
相对于完整阻尼拖拽范围的进度。
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
pullProgress double
相对于有效阈值的进度。
no setter
refreshState MiuixRefreshState
当前刷新视觉状态。
no setter
refreshThreshold double
触发阈值,取值范围为 0 到 1。
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visualProgress double
指示器从零缩放到完整尺寸的进度。
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited