MiuixPullToRefreshDefaults class

下拉刷新的默认值。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

circleSize → const double
color → const Color
Compose Color.Gray 的精确值。
refreshTexts → const List<String>
refreshTextStyle → const TextStyle
refreshThreshold → const double