MiuixRadioButtonColors class

RadioButton 颜色配置。对应 Kotlin RadioButtonColors。

Annotations

Constructors

MiuixRadioButtonColors({required Color selectedColor, required Color disabledSelectedColor})
const

Properties

disabledSelectedColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited