MiuixRadioButtonLocation enum

单选按钮的位置。对应 Kotlin RadioButtonLocation。

Inheritance
Available extensions

Values

start → const MiuixRadioButtonLocation

起始侧(标题之前)。

end → const MiuixRadioButtonLocation

末尾侧(endActions 之后)。

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MiuixRadioButtonLocation>
A constant List of the values in this enum, in order of their declaration.