MiuixRadioButtonPreferenceDefaults class

RadioButtonPreference 默认值。对应 Kotlin RadioButtonPreferenceDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

radioButtonPreferenceColors(BuildContext context) MiuixRadioButtonPreferenceColors
标题与摘要的默认颜色:未选中时使用 onBackground/onSurfaceVariantSummary, 选中时使用 primary