MiuixRangeSlider class
Miuix 风格的范围滑块。对应 Kotlin RangeSlider。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MiuixRangeSlider
Constructors
-
MiuixRangeSlider({Key? key, required double startValue, required double endValue, required ValueChanged<
(double, double)> ? onValueChanged, bool enabled = true, double min = 0.0, double max = 1.0, int steps = 0, VoidCallback? onValueChangeFinished, double height = MiuixSliderDefaults.minHeight, MiuixSliderColors? colors, MiuixSliderHapticEffect hapticEffect = MiuixSliderDefaults.defaultHapticEffect, bool showKeyPoints = false, List<double> ? keyPoints, double magnetThreshold = 0.02}) -
const
Properties
- colors → MiuixSliderColors?
-
final
- enabled → bool
-
final
- endValue → double
-
final
- hapticEffect → MiuixSliderHapticEffect
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
keyPoints
→ List<
double> ? -
final
- magnetThreshold → double
-
final
- max → double
-
final
- min → double
-
final
-
onValueChanged
→ ValueChanged<
(double, double)> ? -
final
- onValueChangeFinished → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showKeyPoints → bool
-
final
- startValue → double
-
final
- steps → int
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MiuixRangeSlider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited