MiuixScrollBarAdapter class

对应 Kotlin ScrollBarAdapter,统一适配 Flutter 的 ScrollController

Constructors

MiuixScrollBarAdapter(ScrollController controller)
const

Properties

contentSize double
no setter
controller ScrollController
final
hashCode int
The hash code for this object.
no setterinherited
maxScrollOffset double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollOffset double
no setter
viewportSize double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollTo(double offset) → void
立即滚动到指定内容偏移,并夹在有效范围内。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited