MiuixScrollBarColors class

对应 Kotlin ScrollBarColors;null 表示 Color.Unspecified

Annotations

Constructors

MiuixScrollBarColors({Color? thumbColor, Color? trackColor})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbColor Color?
final
trackColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited