MiuixScrollBarDefaults class
对应 Kotlin ScrollBarDefaults 的默认值。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColors(
BuildContext context) → MiuixScrollBarColors
Constants
- colors → const MiuixScrollBarColors
- dragAnimationDurationMillis → const int
- dragThumbAlpha → const double
- dragThumbWidth → const double
- endPadding → const double
- fadeDelayMillis → const int
- fadeDurationMillis → const int
- thumbAlpha → const double
- thumbMinLength → const double
- thumbWidth → const double
- touchTargetWidth → const double