MiuixScrollBehavior class abstract

滚动行为抽象。对应 Kotlin ScrollBehavior。

Implementers

Constructors

MiuixScrollBehavior()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPinned → bool
是否固定(不随滚动收起)。
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → MiuixTopAppBarState
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited