MiuixSearchBarDefaults class
对应 Kotlin SearchBarDefaults 的默认值。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- inputFieldFontSize → const double
- inputFieldMinHeight → const double
- insideMargin → const EdgeInsets
- leadingIconEndPadding → const double
- leadingIconStartPadding → const double
- textFadeDuration → const Duration
- trailingIconEndPadding → const double
- trailingIconStartPadding → const double
- visibilityDuration → const Duration