MiuixSliderDefaults class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sliderColors(BuildContext context) MiuixSliderColors

Constants

defaultHapticEffect → const MiuixSliderHapticEffect
默认触感反馈类型。
dragOverlayAlpha → const double
拖拽时的背景压暗 alpha。
keyPointRadius → const double
关键点半径。
minHeight → const double
Slider / RangeSlider 的最小高度(水平)或宽度(垂直)。
thumbRadiusRatio → const double
thumb 实际半径相对轨道半径的比例。
thumbScaleActive → const double
thumb 在按下/拖拽/悬停时的放大系数。