MiuixSmallTitle class

小标题。对应 Kotlin SmallTitle。

使用 subtitle 样式(14sp 加粗),默认颜色 onBackgroundVariant, 内边距 28dp × 8dp。

Inheritance

Constructors

MiuixSmallTitle(String text, {Key? key, Color? textColor, EdgeInsetsGeometry insideMargin = const EdgeInsets.symmetric(horizontal: 28, vertical: 8)})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
insideMargin → EdgeInsetsGeometry
内边距,默认 28dp 水平 + 8dp 垂直。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
textColor → Color?
文字颜色,默认 MiuixTheme.colors.onBackgroundVariant。
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited