MiuixSmallTopAppBar class

小标题静态 TopAppBar。对应 Kotlin SmallTopAppBar

不参与折叠/展开,固定显示居中标题。如传入 scrollBehavior, 会把 state 的 MiuixTopAppBarState.heightOffsetLimit 锁为 0 (pinned 效果),让共享同一 behavior 的其他 TopAppBar 仍可正常滚动。

Inheritance

Constructors

MiuixSmallTopAppBar({Key? key, required String title, Color? color, Color? titleColor, String subtitle = '', Color? subtitleColor, Widget? navigationIcon, List<Widget>? actions, MiuixScrollBehavior? scrollBehavior, bool defaultWindowInsetsPadding = true, double titlePadding = MiuixTopAppBarDefaults.titlePadding, double navigationIconPadding = MiuixTopAppBarDefaults.navigationIconPadding, double actionIconPadding = MiuixTopAppBarDefaults.actionIconPadding, Widget? bottomContent})
const

Properties

actionIconPadding double
final
actions List<Widget>?
final
bottomContent Widget?
final
color Color?
final
defaultWindowInsetsPadding bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior MiuixScrollBehavior?
final
subtitle String
final
subtitleColor Color?
final
title String
final
titleColor Color?
final
titlePadding double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited