MiuixSnackbarDefaults class

Snackbar 默认值。对应 Kotlin SnackbarDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

snackbarColors(BuildContext context) MiuixSnackbarColors
从当前主题创建默认 Snackbar 颜色。对应 Kotlin snackbarColors

Constants

actionCornerRadius → const double
操作标签胶囊的默认圆角半径。
actionInsideMargin → const EdgeInsets
操作标签胶囊的默认内部边距。
cornerRadius → const double
默认圆角半径。
insideMargin → const EdgeInsets
默认内部边距。
outerPadding → const EdgeInsets
默认外部边距。