MiuixSpringDefaults class

对应 Kotlin SpringMath 里的常量集合。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

criticalDampingRatio → const double
临界阻尼比。
highVelocityThreshold → const double
高初速度阈值,超过后使用较慢自然周期。
maxFrameDeltaSeconds → const double
单帧最大步长(秒)。
minFrameDeltaSeconds → const double
单帧最小步长(秒)。
slowerSpringPeriodForHighVelocity → const double
高速时使用的自然周期(秒)。
standardSpringPeriod → const double
标准自然周期(秒)。