MiuixSpringOperator class

对应 Kotlin SpringOperator,以显式欧拉法计算下一帧速度。

Annotations

Constructors

MiuixSpringOperator({required double dampingRatio, required double naturalPeriod})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateVelocity({required double currentVelocity, required double deltaTime, required double currentPosition, required double targetPosition}) double
根据当前位置、目标位置和帧间隔计算新速度。

Operators

operator ==(Object other) bool
The equality operator.
inherited