MiuixSwitchColors class

Switch 颜色配置。对应 Kotlin SwitchColors

Annotations

Constructors

MiuixSwitchColors({required Color checkedThumbColor, required Color uncheckedThumbColor, required Color disabledCheckedThumbColor, required Color disabledUncheckedThumbColor, required Color checkedTrackColor, required Color uncheckedTrackColor, required Color disabledCheckedTrackColor, required Color disabledUncheckedTrackColor})
const

Properties

checkedThumbColor Color
final
checkedTrackColor Color
final
disabledCheckedThumbColor Color
final
disabledCheckedTrackColor Color
final
disabledUncheckedThumbColor Color
final
disabledUncheckedTrackColor Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uncheckedThumbColor Color
final
uncheckedTrackColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited