MiuixSwitchDefaults class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

switchColors(BuildContext context) MiuixSwitchColors

Constants

thumbOffsetOff → const double
thumbOffsetOn → const double
thumbScaleActive → const double
thumbSize → const double
trackHeight → const double
trackWidth → const double