MiuixTabRow class

对应 Kotlin TabRow 的 Miuix 标签栏。

Inheritance

Constructors

MiuixTabRow({Key? key, required List<String> tabs, required int selectedTabIndex, required ValueChanged<int> onTabSelected, MiuixTabRowColors? colors, double minWidth = MiuixTabRowDefaults.tabRowMinWidth, double maxWidth = MiuixTabRowDefaults.tabRowMaxWidth, double height = MiuixTabRowDefaults.tabRowHeight, double cornerRadius = MiuixTabRowDefaults.tabRowCornerRadius, double itemSpacing = MiuixTabRowDefaults.tabRowItemSpacing, AlignmentGeometry contentAlignment = Alignment.center, ScrollController? scrollController})
const

Properties

colors → MiuixTabRowColors?
final
contentAlignment → AlignmentGeometry
final
cornerRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
itemSpacing → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidth → double
final
minWidth → double
final
onTabSelected → ValueChanged<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
final
selectedTabIndex → int
final
tabs → List<String>
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited