MiuixTabRowDefaults class
对应 Kotlin TabRowDefaults 的默认值。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColors(
BuildContext context) → MiuixTabRowColors
Constants
- borderWidth → const double
- contourItemSpacing → const double
- contourPadding → const double
- itemHorizontalPadding → const double
- tabRowCornerRadius → const double
- tabRowHeight → const double
- tabRowItemSpacing → const double
- tabRowMaxWidth → const double
- tabRowMinWidth → const double
- tabRowWithContourCornerRadius → const double
- tabRowWithContourHeight → const double
- tabRowWithContourMaxWidth → const double
- tabRowWithContourMinWidth → const double