MiuixText class

Miuix 风格的文本。对应 Kotlin Text。

默认 style 为 MiuixTheme.textStyles.main,颜色取自 MiuixContentColor, 显式 color 优先级最高。

Inheritance

Constructors

MiuixText(String text, {Key? key, Color? color, double? fontSize, FontWeight? fontWeight, String? fontFamily, double? letterSpacing, FontStyle? fontStyle, TextDecoration? decoration, TextAlign? textAlign, double? height, int? maxLines, TextOverflow? overflow, bool softWrap = true, TextStyle? style})
const

Properties

color → Color?
final
decoration → TextDecoration?
final
fontFamily → String?
final
fontSize → double?
final
fontStyle → FontStyle?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterSpacing → double?
final
maxLines → int?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softWrap → bool
final
style → TextStyle?
基础样式。默认 MiuixTheme.textStyles.main。
final
text → String
final
textAlign → TextAlign?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited