MiuixToolbarPosition enum

悬浮工具栏在 MiuixScaffold 中的位置。对应 Kotlin ToolbarPosition

枚举顺序与 Kotlin 的整型值一一对应(TopStart=0 … BottomCenter=7)。

Inheritance
Available extensions

Values

topStart → const MiuixToolbarPosition
centerStart → const MiuixToolbarPosition
bottomStart → const MiuixToolbarPosition
topEnd → const MiuixToolbarPosition
centerEnd → const MiuixToolbarPosition
bottomEnd → const MiuixToolbarPosition
topCenter → const MiuixToolbarPosition
bottomCenter → const MiuixToolbarPosition

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MiuixToolbarPosition>
A constant List of the values in this enum, in order of their declaration.