MiuixTooltipBox class

tooltip 锚定到 child,支持鼠标悬停、触摸长按及状态控制。

Inheritance

Constructors

MiuixTooltipBox({Key? key, required Widget tooltip(BuildContext context, MiuixTooltipScope scope), required Widget child, MiuixTooltipState? state, MiuixTooltipAnchorPosition positioning = MiuixTooltipAnchorPosition.below, double spacing = MiuixTooltipDefaults.spacingBetweenTooltipAndAnchor, bool focusable = false, bool enableUserInput = true, String semanticLabel = '显示提示'})
const

Properties

child Widget
final
enableUserInput bool
final
focusable bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
positioning MiuixTooltipAnchorPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String
final
spacing double
final
state MiuixTooltipState?
final
tooltip Widget Function(BuildContext context, MiuixTooltipScope scope)
Tooltip 槽。通过 scope 可获得实际方位和锚点边界。
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MiuixTooltipBox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited