MiuixVectorIconPainter class
将 MiuixVectorIcon 绘制到 视口尺寸 的画布上;外层缩放交给 FittedBox。
tint 非空时以 ColorFilter.tint(默认 BlendMode.srcIn)对整幅矢量上色,
与 Compose Icon(painter, colorFilter = ColorFilter.tint(tint)) 一致:
各子路径先按各自 alpha 合成,再被 tint 统一着色(保留分层透明度)。
tint 为空时按矢量原始颜色绘制(多色/不上色场景)。
- Inheritance
-
- Object
- Listenable
- CustomPainter
- MiuixVectorIconPainter
Constructors
- MiuixVectorIconPainter(MiuixVectorIcon icon, {Color? tint})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → MiuixVectorIcon
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- tint → Color?
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant MiuixVectorIconPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited