MiuixWindowBottomSheet class
窗口级底部抽屉。对应 Kotlin WindowBottomSheet。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MiuixWindowBottomSheet
Constructors
- MiuixWindowBottomSheet({Key? key, required bool show, String? title, Widget? startAction, Widget? endAction, Color? backgroundColor, bool enableWindowDim = true, double cornerRadius = MiuixBottomSheetDefaults.cornerRadius, double sheetMaxWidth = MiuixBottomSheetDefaults.maxWidth, VoidCallback? onDismissRequest, VoidCallback? onDismissFinished, Size outsideMargin = MiuixBottomSheetDefaults.outsideMargin, Size insideMargin = MiuixBottomSheetDefaults.insideMargin, bool defaultWindowInsetsPadding = true, Color? dragHandleColor, bool allowDismiss = true, bool enableNestedScroll = true, required Widget content})
-
const
Properties
- allowDismiss → bool
-
final
- backgroundColor → Color?
-
final
- content → Widget
-
final
- cornerRadius → double
-
final
- defaultWindowInsetsPadding → bool
-
final
- dragHandleColor → Color?
-
final
- enableNestedScroll → bool
-
final
- enableWindowDim → bool
-
final
- endAction → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insideMargin → Size
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDismissFinished → VoidCallback?
-
final
- onDismissRequest → VoidCallback?
-
final
- outsideMargin → Size
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheetMaxWidth → double
-
final
- show → bool
-
final
- startAction → Widget?
-
final
- title → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited