SquircleDefaults class

Squircle 共享默认常量。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

extension → const double
圆角瓦片尺寸相对 cornerRadius 的倍数。1.0=圆弧,1.1=连续圆角。
extensionMax → const double
extension 的上限。
extensionMin → const double
extension 的下限。