transformInternal method
Returns the value of the curve at point t.
The given parametric value t will be between 0.0 and 1.0, inclusive.
Implementation
@override
double transformInternal(double t) {
if (factor == 1.0) return t * t;
return math.pow(t, 2 * factor).toDouble();
}