BlendColorEntry class
叠加在模糊背景上的单个颜色 blend。对应 Kotlin BlendColorEntry。
- Annotations
Constructors
- BlendColorEntry(Color color, [BlurBlendMode mode = BlurBlendMode.srcOver])
-
const
Properties
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mode → BlurBlendMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override