BloomStroke class

边缘 bloom 描边的着色模型。对应 Kotlin BloomStroke。

color 平铺描边色(其 alpha 缩放描边贡献);blendMode 合成模式(默认 plus); innerBlurRadius 内发光深度(dp);primaryLight/secondaryLight 两个方向光; dualPeak 每光是否产生两个对峰(Apple 风镜面扫光)。

Annotations

Constructors

BloomStroke({Color color = const Color(0x0DFFFFFF), BlendMode blendMode = BlendMode.plus, double innerBlurRadius = 2.8, LightSource primaryLight = const LightSource(position: LightPosition(0.5, 0.5, -0.5), intensity: 0.4), LightSource secondaryLight = const LightSource(position: LightPosition(0.5, 0.8, -0.5), intensity: 0.25), bool dualPeak = false})
const

Properties

blendMode → BlendMode
final
color → Color
final
dualPeak → bool
final
hashCode → int
The hash code for this object.
no setterinherited
innerBlurRadius → double
final
primaryLight → LightSource
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryLight → LightSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited