transformInternal method
Returns the value of the curve at point t.
The given parametric value t will be between 0.0 and 1.0, inclusive.
Implementation
@override
double transformInternal(double t) {
final inv = 1.0 - t;
if (factor == 1.0) return 1.0 - inv * inv;
return 1.0 - math.pow(inv, 2 * factor).toDouble();
}