Hsv class
对应 Kotlin Hsv,采用便于用户理解的归一化区间的 HSV 表示。
- Annotations
Properties
- h → double
-
对应 Kotlin
h:色相,单位度,取值[0, 360]。final - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s → double
-
对应 Kotlin
s:饱和度,百分比,取值[0, 100]。final - v → double
-
对应 Kotlin
v:明度/亮度,百分比,取值[0, 100]。final
Methods
-
copyWith(
{double? h, double? s, double? v}) → Hsv -
返回替换指定分量后的副本,对应 Kotlin data class 的
copy。 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColor(
[double alpha = 1.0]) → Color -
对应 Kotlin
Hsv.toColor,将 HSV 转换为 sRGB Color。 -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override