MiuixArrowPreference class
带右箭头的偏好设置行。对应 Kotlin ArrowPreference。
在 MiuixBasicComponent 的末尾追加一个 10×16 的右箭头图标,
颜色取自 MiuixArrowPreferenceDefaults.endActionColors。
RTL 布局下箭头自动水平翻转。点击行为复用 MiuixBasicComponent 的
点击/按压/holdDownState/enabled 语义。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MiuixArrowPreference
Constructors
-
MiuixArrowPreference({Key? key, required String title, MiuixBasicComponentColors? titleColor, String? summary, MiuixBasicComponentColors? summaryColor, Widget? startAction, List<
Widget> ? endActions, Widget? bottomAction, EdgeInsetsGeometry insideMargin = MiuixBasicComponentDefaults.insideMargin, VoidCallback? onClick, bool holdDownState = false, bool enabled = true}) -
const
Properties
- bottomAction → Widget?
-
底部内容(可选),位于主行下方。
final
- enabled → bool
-
是否启用。
final
-
endActions
→ List<
Widget> ? -
末尾箭头之前的额外内容(可选);以
Row排列,水平方向min大小, 末端 8dp 间距,并以Flexible(loose)容纳,避免与箭头争抢空间。final - hashCode → int
-
The hash code for this object.
no setterinherited
- holdDownState → bool
-
是否处于按压态(用于外部强制按下视觉效果)。
final
- insideMargin → EdgeInsetsGeometry
-
内边距,默认 MiuixBasicComponentDefaults.insideMargin。
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClick → VoidCallback?
-
点击回调;为 null 时不可点击。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAction → Widget?
-
起始侧内容(可选)。
final
- summary → String?
-
行摘要(可选)。
final
- summaryColor → MiuixBasicComponentColors?
-
摘要颜色;为 null 时取 MiuixBasicComponentDefaults.summaryColor。
final
- title → String
-
行标题。
final
- titleColor → MiuixBasicComponentColors?
-
标题颜色;为 null 时取 MiuixBasicComponentDefaults.titleColor。
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited