MiuixBadgeDefaults class

Badge 默认值。对应 Kotlin BadgeDefaults。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

containerColor(BuildContext context) → Color
默认容器色,对应主题的 error。
contentColor(BuildContext context) → Color
默认内容色,对应主题的 onError。

Constants

largeSize → const double
含内容徽标的默认最小尺寸。
size → const double
无内容圆点徽标的默认尺寸。