MiuixBasicIcons class
基础图标命名空间。对应 Kotlin MiuixIcons.Basic 上的一组扩展属性。
每个 getter 返回一个 MiuixVectorIcon,与 Kotlin 端相同:懒加载缓存单例, 保证同一图标只构建一次。
Properties
- arrowRight → MiuixVectorIcon
-
右向箭头(
>)。源自icon/basic/ArrowRight.kt,视口 10x16。no setter - arrowUpDown → MiuixVectorIcon
-
上下双箭头。源自
icon/basic/ArrowUpDown.kt,视口 10x16。no setter - check → MiuixVectorIcon
-
勾选。源自
icon/basic/Check.kt,视口 56x56。no setter - close → MiuixVectorIcon
-
关闭(
x,描边)。源自icon/basic/Close.kt,视口 24x24。no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- search → MiuixVectorIcon
-
搜索(放大镜)。源自
icon/basic/Search.kt,视口 20x20。no setter - searchCleanup → MiuixVectorIcon
-
搜索清除(圆底 x)。源自
icon/basic/SearchCleanup.kt,视口 68x68。no setter -
侧边栏。源自
icon/basic/Sidebar.kt,视口 1224x1224(含纵向翻转)。no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited