MiuixBlurDefaults class
模糊效果默认值。对应 Kotlin BlurDefaults + BlurEffect.kt 内部常量。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
blurColors(
{List< BlendColorEntry> blendColors = const [], double brightness = 0.0, double contrast = 1.0, double saturation = 1.0}) → BlurColors -
便捷构造 BlurColors。对应
BlurDefaults.blurColors。
Constants
- blurKernelReach → const int
-
模糊核触及范围(源像素)。对应
BLUR_KERNEL_REACH。 - blurRadius → const double
-
默认模糊半径(dp)。对应
BlurDefaults.BlurRadius。 - blurRadiusToSigma → const double
-
模糊半径 → 高斯 sigma 的转换系数。对应
BLUR_RADIUS_TO_SIGMA。 - maxBlurRadius → const double
-
最大模糊半径(dp)。对应
BlurDefaults.MaxBlurRadius。 - noiseCoefficient → const double
-
默认噪声抖动系数(抗色带)。对应
BlurDefaults.NoiseCoefficient。 - progressiveNoiseCoefficient → const double
-
progressive blur 的默认噪声系数(0=禁用)。对应
BlurDefaults.ProgressiveNoiseCoefficient。