MiuixButtonColors class
Button 颜色配置。对应 Kotlin ButtonColors。
- Annotations
Constructors
- MiuixButtonColors({required Color color, required Color disabledColor, required Color contentColor, required Color disabledContentColor})
-
const
Properties
- color → Color
-
final
- contentColor → Color
-
final
- disabledColor → Color
-
final
- disabledContentColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited