MiuixButtonDefaults class
Button 默认值。对应 Kotlin ButtonDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
- 默认次级按钮颜色。
- 主色按钮颜色。
Constants
- cornerRadius → const double
- insideMargin → const EdgeInsets
- minHeight → const double
- minWidth → const double