MiuixCheckboxColors class

Checkbox 颜色配置。对应 Kotlin CheckboxColors。

Annotations

Constructors

MiuixCheckboxColors({required Color checkedForegroundColor, required Color uncheckedForegroundColor, required Color disabledCheckedForegroundColor, required Color disabledUncheckedForegroundColor, required Color checkedBackgroundColor, required Color uncheckedBackgroundColor, required Color disabledCheckedBackgroundColor, required Color disabledUncheckedBackgroundColor})
const

Properties

checkedBackgroundColor → Color
final
checkedForegroundColor → Color
final
disabledCheckedBackgroundColor → Color
final
disabledCheckedForegroundColor → Color
final
disabledUncheckedBackgroundColor → Color
final
disabledUncheckedForegroundColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uncheckedBackgroundColor → Color
final
uncheckedForegroundColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited