MiuixColorPaletteDefaults class
MiuixColorPalette 的默认尺寸与网格参数。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- controlHeight → const double
- 颜色预览和透明度滑块的高度。
- cornerRadius → const double
- 调色板网格的默认圆角半径。
- hueColumns → const int
- 默认色相列数。
- includeGrayColumn → const bool
- 默认显示灰阶列。
- indicatorRadius → const double
- 选中指示器的默认半径。
- paletteHeight → const double
- 调色板网格高度。
- rows → const int
- 默认色彩行数。
- showPreview → const bool
- 默认显示颜色预览。
- spacing → const double
- 子项之间的垂直间距。