MiuixDropdownColors class
下拉选项行使用的颜色。对应 Kotlin DropdownColors(旧别名 SpinnerColors)。
- Annotations
Constructors
Properties
- containerColor → Color
-
未选中项的背景颜色。
final
- contentColor → Color
-
未选中项的文本颜色。
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedContainerColor → Color
-
选中项的背景颜色。
final
- selectedContentColor → Color
-
选中项的文本颜色。
final
- selectedIndicatorColor → Color
-
选中指示图标(勾号)的颜色。
final
- selectedSummaryColor → Color
-
选中项的摘要文本颜色。
final
- summaryColor → Color
-
未选中项的摘要文本颜色。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override