MiuixFabPosition enum
悬浮操作按钮(FAB)在 MiuixScaffold 中的位置。对应 Kotlin FabPosition。
Values
- start → const MiuixFabPosition
-
底部起始侧,位于底栏(若存在)上方。
- center → const MiuixFabPosition
-
底部居中,位于底栏(若存在)上方。
- end → const MiuixFabPosition
-
底部结束侧,位于底栏(若存在)上方。
- endOverlay → const MiuixFabPosition
-
底部结束侧,覆盖在底栏(若存在)之上。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MiuixFabPosition> - A constant List of the values in this enum, in order of their declaration.