MiuixFloatingNavigationBar class
悬浮式底部导航栏。对应 Kotlin FloatingNavigationBar。
内容按自身宽度排列,不参与等分;项目之间固定间隔 12。阴影的几何固定为 黑色 20%、blurRadius=10,shadowElevation 仅控制是否显示阴影。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MiuixFloatingNavigationBar
Constructors
-
const
Properties
-
children
→ List<
Widget> -
final
- color → Color?
-
final
- colors → MiuixNavigationBarColors?
-
final
- cornerRadius → double
-
final
- defaultWindowInsetsPadding → bool
-
是否应用默认 caption-bar inset。移动端该 inset 为 0;保留此参数以对齐源 API。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalAlignment → AlignmentGeometry
-
final
- horizontalOutSidePadding → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowElevation → double
-
final
- showDivider → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited