MiuixFloatingToolbarDefaults class
FloatingToolbar 默认值。对应 Kotlin FloatingToolbarDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColor(
BuildContext context) → Color -
默认背景色,取自主题的
surfaceContainer。
Constants
- cornerRadius → const double
- 默认圆角半径(逻辑像素)。cornerRadius=50 配合较矮的工具栏高度会形成胶囊轮廓。
- outSidePadding → const EdgeInsets
-
工具栏外部留白,对应 Kotlin
PaddingValues(12.dp, 8.dp)。