MiuixGlassBackground class
对应 Kotlin GlassBackground。
- Annotations
Constructors
- MiuixGlassBackground({required double saturation, required double brightness, required double burn, required double unShade})
-
const
Properties
- brightness → double
-
final
- burn → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturation → double
-
final
- unShade → double
-
final
Methods
-
copyWith(
{double? saturation, double? brightness, double? burn, double? unShade}) → MiuixGlassBackground -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited