MiuixGlassColorBlendMode enum

对应 Kotlin GlassColorBlendMode;顺序与 OS4 blend shader 的 id 一致。

Inheritance
Available extensions

Values

srcOver → const MiuixGlassColorBlendMode
plusDarker → const MiuixGlassColorBlendMode
plusLighter → const MiuixGlassColorBlendMode
softLight → const MiuixGlassColorBlendMode
hardLight → const MiuixGlassColorBlendMode
overlay → const MiuixGlassColorBlendMode
luminosity → const MiuixGlassColorBlendMode
colorDodge → const MiuixGlassColorBlendMode
colorBurn → const MiuixGlassColorBlendMode

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MiuixGlassColorBlendMode>
A constant List of the values in this enum, in order of their declaration.