MiuixGlassLight class
对应 Kotlin GlassLight。
- Annotations
Constructors
Properties
- angleRange → double
-
final
- directionX → double
-
final
- directionY → double
-
final
- directionZ → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intensity → double
-
final
- oppositeIntensity → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? directionX, double? directionY, double? directionZ, double? intensity, double? oppositeIntensity, double? angleRange}) → MiuixGlassLight -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited