MiuixGlassMaterial class
对应 Kotlin GlassMaterial:模糊半径与至多三层独立混色。
- Annotations
Constructors
- MiuixGlassMaterial({required double blurRadius, required MiuixGlassColorLayer first, MiuixGlassColorLayer? second, MiuixGlassColorLayer? third})
-
const
Properties
- blurRadius → double
-
final
- first → MiuixGlassColorLayer
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
layers
→ List<
MiuixGlassColorLayer> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → MiuixGlassColorLayer?
-
final
- third → MiuixGlassColorLayer?
-
final
Methods
-
copyWith(
{double? blurRadius}) → MiuixGlassMaterial -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override