MiuixGlassPanel class
对应 Kotlin Modifier.glassPanel,默认附带 Regular 阴影。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MiuixGlass
- MiuixGlassPanel
Constructors
- MiuixGlassPanel({Key? key, MiuixBackdrop? backdrop, MiuixGlassStyle? style, MiuixGlassMaterial? material, MiuixGlassMaterial? underlayMaterial, MiuixGlassShape shape = const MiuixGlassShape(), double alpha = 1, Color? tint, Color? fill, MiuixGlassStroke? stroke, MiuixGlassShadow? shadow = MiuixGlassShadows.regular, bool shading = true, bool enabled = true, required Widget child})
-
const
Properties
- alpha → double
-
finalinherited
- backdrop → MiuixBackdrop?
-
finalinherited
- child → Widget
-
finalinherited
- enabled → bool
-
finalinherited
- fill → Color?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- material → MiuixGlassMaterial?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shading → bool
-
finalinherited
- shadow → MiuixGlassShadow?
-
finalinherited
- shape → MiuixGlassShape
-
finalinherited
- stroke → MiuixGlassStroke?
-
finalinherited
- style → MiuixGlassStyle?
-
finalinherited
- tint → Color?
-
finalinherited
- underlayMaterial → MiuixGlassMaterial?
-
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MiuixGlass> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited