MiuixGlassTopAppBar class
对应 Kotlin GlassTopAppBar。操作区使用 MiuixGlassIconButton,旧顶栏保持不变。 isContentScrolled 传入列表是否离开顶部,避免标题锁定折叠后材质不能复位。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MiuixGlassTopAppBar
Constructors
-
MiuixGlassTopAppBar({Key? key, required String title, MiuixBackdrop? backdrop, String? largeTitle, String subtitle = '', MiuixScrollBehavior? scrollBehavior, bool? isContentScrolled, MiuixGlassStyle? style, double alpha = 1, double titleAlpha = 1, double buttonSize = 44, double largeTitleBlurRadius = 12, double bandOverhang = 28, double bandHeightFactor = 1, Gradient? bandBrush, double bandBlurRadius = 24, bool defaultWindowInsetsPadding = true, List<
Widget> actions = const [], Widget? bottomContent}) -
const
Properties
-
actions
→ List<
Widget> -
final
- alpha → double
-
final
- backdrop → MiuixBackdrop?
-
final
- bandBlurRadius → double
-
band 区域对身后内容的实时高斯模糊半径(sigma,dp)。0 关闭模糊,只剩
bandBrush 色调层。默认 24,与 MiuixTopAppBar.blurred 的默认一致。
final
- bandBrush → Gradient?
-
final
- bandHeightFactor → double
-
band 实际高度占「顶栏高度 + bandOverhang」的比例,从顶部量起。
默认 1;调小可让模糊带更矮(色调渐变与淡出遮罩按缩短后的高度重新铺开,
下缘仍平滑淡出)。取值 (0, 1]。
final
- bandOverhang → double
-
final
- bottomContent → Widget?
-
final
-
final
- defaultWindowInsetsPadding → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isContentScrolled → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- largeTitle → String?
-
final
- largeTitleBlurRadius → double
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollBehavior → MiuixScrollBehavior?
-
final
- style → MiuixGlassStyle?
-
final
- subtitle → String
-
final
- title → String
-
final
- titleAlpha → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited