MiuixListPopupDefaults class
ListPopup 的尺寸、动效与默认位置策略。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
dropdownPositionProvider(
{double verticalMargin = 8, double horizontalMargin = 0}) → MiuixPopupPositionProvider - 创建下拉菜单的位置策略。
Constants
- alphaEnterAnimationSpec → const MiuixPopupTweenSpec
- alphaExitAnimationSpec → const MiuixPopupTweenSpec
- contextMenuPosition → const MiuixPopupPositionProvider
- cornerRadius → const double
- dimEnterAnimationSpec → const MiuixPopupTweenSpec
- dimExitAnimationSpec → const MiuixPopupTweenSpec
- fractionAnimationSpec → const MiuixPopupSpringSpec
- minPopupHeight → const double
- minWidth → const double
- resetAnimationSpec → const MiuixPopupSpringSpec