MiuixListPopupLayoutInfo class
popup host 定位、缩放与揭示动画所需的完整布局信息。
- Annotations
Constructors
- MiuixListPopupLayoutInfo({required Rect windowBounds, required EdgeInsets popupMargin, required Offset calculatedOffset, required Offset effectiveTransformOrigin, required Offset localTransformOrigin, required MiuixPopupLayoutPosition popupLayoutPosition})
-
const
Properties
- calculatedOffset → Offset
-
弹窗左上角窗口坐标。内容尚未测量时为 Offset.zero。
final
- effectiveTransformOrigin → Offset
-
归一化的窗口坐标原点,供统一 popup host 的全局动效使用。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localTransformOrigin → Offset
-
归一化的弹窗局部原点,供 MiuixListPopupContent 使用。
final
- popupLayoutPosition → MiuixPopupLayoutPosition
-
final
- popupMargin → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windowBounds → Rect
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited