MiuixNavigationBar class

普通底部导航栏。对应 Kotlin NavigationBar。

children 通常由 2 到 5 个 MiuixNavigationBarItem 组成;每项会被 Expanded 等分。底部系统区在 iOS 固定为 20,其余平台使用 MediaQuery.viewPadding.bottom。Compose 的 caption-bar inset 在移动端恒为 0,Flutter 没有等价 API,因此不额外增加 caption-bar 高度。

Inheritance

Constructors

MiuixNavigationBar({Key? key, required List<Widget> children, Color? color, MiuixNavigationBarColors? colors, bool showDivider = true, bool defaultWindowInsetsPadding = true, MiuixNavigationBarDisplayMode mode = MiuixNavigationBarDisplayMode.iconAndText})
const

Properties

children → List<Widget>
final
color → Color?
final
colors → MiuixNavigationBarColors?
final
defaultWindowInsetsPadding → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode → MiuixNavigationBarDisplayMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDivider → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited