MiuixNavigationBarDefaults class
普通导航栏默认值。对应 Kotlin NavigationBarDefaults。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultColors(
BuildContext context) → MiuixNavigationBarColors - 从当前 Miuix 主题创建导航栏默认颜色。
Constants
- bottomPadding → const double
- iconSize → const double
- iconTopPadding → const double
- itemHeight → const double
- labelFontSize → const double
- selectedPressedAlpha → const double
- selectionAnimationDuration → const Duration
- unselectedAlpha → const double
- unselectedPressedAlpha → const double