MiuixNavigationRailDefaults class

NavigationRail 默认值。对应 Kotlin NavigationRailDefaults。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

colors(BuildContext context) → MiuixNavigationRailColors
从当前 Miuix 主题创建默认颜色。