MiuixNumberPickerColors class
NumberPicker 颜色配置。对应 Kotlin NumberPickerColors。
- Annotations
Constructors
- MiuixNumberPickerColors({required Color selectedTextColor, required Color unselectedTextColor, required Color disabledSelectedTextColor, required Color disabledUnselectedTextColor})
-
const
Properties
- disabledSelectedTextColor → Color
-
final
- disabledUnselectedTextColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTextColor → Color
-
final
- unselectedTextColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectedTextColorFor(
bool enabled) → Color -
toString(
) → String -
A string representation of this object.
inherited
-
unselectedTextColorFor(
bool enabled) → Color
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited