MiuixOverlayDialog class
Scaffold 内 Miuix 对话框。对应 Kotlin OverlayDialog。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MiuixOverlayDialog
Constructors
- MiuixOverlayDialog({Key? key, required bool show, String? title, Color? titleColor, String? summary, Color? summaryColor, Color? backgroundColor, bool enableWindowDim = true, VoidCallback? onDismissRequest, VoidCallback? onDismissFinished, Size outsideMargin = MiuixDialogDefaults.outsideMargin, Size insideMargin = MiuixDialogDefaults.insideMargin, bool defaultWindowInsetsPadding = true, bool renderInRootScaffold = true, double maxWidth = MiuixDialogDefaults.maxWidth, bool? largeScreen, double? cornerRadius, required Widget content})
-
const
Properties
- backgroundColor → Color?
-
final
- content → Widget
-
final
- cornerRadius → double?
-
final
- defaultWindowInsetsPadding → bool
-
final
- enableWindowDim → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insideMargin → Size
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- largeScreen → bool?
-
final
- maxWidth → double
-
final
- onDismissFinished → VoidCallback?
-
final
- onDismissRequest → VoidCallback?
-
final
- outsideMargin → Size
-
final
- renderInRootScaffold → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show → bool
-
final
- summary → String?
-
final
- summaryColor → Color?
-
final
- title → String?
-
final
- titleColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MiuixOverlayDialog> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited