MiuixOverlayDropdownDialog class
Scaffold 内下拉对话框(单分组)。对应 Kotlin OverlayDropdownDialog(entry)。
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MiuixOverlayDropdownDialog
Constructors
- MiuixOverlayDropdownDialog({Key? key, required MiuixDropdownEntry? entry, required String title, required String dialogButtonString, required bool show, required VoidCallback onDismiss, required VoidCallback onDismissFinished, required MiuixDropdownColors dropdownColors, bool renderInRootScaffold = true, bool? collapseOnSelection = true})
-
const
-
MiuixOverlayDropdownDialog.entries({Key? key, required List<
MiuixDropdownEntry> entries, required String title, required String dialogButtonString, required bool show, required VoidCallback onDismiss, required VoidCallback onDismissFinished, required MiuixDropdownColors dropdownColors, bool renderInRootScaffold = true, bool? collapseOnSelection}) -
Scaffold 内下拉对话框(多分组)。对应 Kotlin
OverlayDropdownDialog(entries)。const
Properties
- collapseOnSelection → bool?
-
final
- dialogButtonString → String
-
final
- dropdownColors → MiuixDropdownColors
-
final
-
effectiveEntries
→ List<
MiuixDropdownEntry> -
no setter
-
entries
→ List<
MiuixDropdownEntry> -
final
- entry → MiuixDropdownEntry?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDismiss → VoidCallback
-
final
- onDismissFinished → VoidCallback
-
final
- renderInRootScaffold → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show → bool
-
final
- title → String
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited