MiuixPopupSpringSpec class

Compose spring 的 Flutter 等价描述。

Annotations

Constructors

MiuixPopupSpringSpec({required double dampingRatio, required double stiffness, required double visibilityThreshold})
const

Properties

dampingRatio → double
final
description → SpringDescription
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stiffness → double
final
visibilityThreshold → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simulation(double from, double to, {double velocity = 0}) → SpringSimulation
创建供 AnimationController.unbounded().animateWith(...) 使用的模拟。
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited