MiuixProgressIndicatorColors class
进度指示器颜色配置。对应 Kotlin ProgressIndicatorColors。
- Annotations
Constructors
- MiuixProgressIndicatorColors({required Color foregroundColor, required Color disabledForegroundColor, required Color backgroundColor})
-
const
Properties
- backgroundColor → Color
-
轨道背景色。
final
- disabledForegroundColor → Color
-
禁用时的前景色。
final
- foregroundColor → Color
-
启用时的前景色。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
background(
) → Color - 返回轨道背景色。
-
foreground(
bool enabled) → Color -
根据
enabled返回前景色。 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited