MiuixRadioButtonPreferenceColors class
RadioButtonPreference 标题与摘要的颜色配置。
对应 Kotlin RadioButtonPreferenceColors。
根据 selected 切换 titleColor/summaryColor:选中时使用 selected*Color,
否则使用基础 *Color。
- Annotations
Constructors
- MiuixRadioButtonPreferenceColors({required MiuixBasicComponentColors titleColor, required MiuixBasicComponentColors selectedTitleColor, required MiuixBasicComponentColors summaryColor, required MiuixBasicComponentColors selectedSummaryColor})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedSummaryColor → MiuixBasicComponentColors
-
final
- selectedTitleColor → MiuixBasicComponentColors
-
final
- summaryColor → MiuixBasicComponentColors
-
final
- titleColor → MiuixBasicComponentColors
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveSummaryColor(
bool selected) → MiuixBasicComponentColors -
根据
selected返回当前摘要颜色。 -
resolveTitleColor(
bool selected) → MiuixBasicComponentColors -
根据
selected返回当前标题颜色。 -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited