MiuixSliderColors class
Slider 颜色配置。对应 Kotlin SliderColors。
- Annotations
Constructors
- MiuixSliderColors({required Color foregroundColor, required Color disabledForegroundColor, required Color backgroundColor, required Color disabledBackgroundColor, required Color thumbColor, required Color disabledThumbColor, required Color keyPointColor, required Color keyPointForegroundColor})
-
const
Properties
- backgroundColor → Color
-
final
- disabledBackgroundColor → Color
-
final
- disabledForegroundColor → Color
-
final
- disabledThumbColor → Color
-
final
- foregroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyPointColor → Color
-
final
- keyPointForegroundColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbColor → Color
-
final
Methods
-
backgroundColorFor(
bool enabled) → Color -
foregroundColorFor(
bool enabled) → Color -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
thumbColorFor(
bool enabled) → Color -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited