MiuixSnackbarCustomDuration class final

Snackbar 自定义显示时长。对应 Kotlin SnackbarDuration.Custom。

Inheritance

Constructors

MiuixSnackbarCustomDuration(int durationMillis)
const

Properties

durationMillis → int
显示毫秒数。
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited