Snackbar 的交互数据。对应 Kotlin SnackbarData。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visuals → MiuixSnackbarVisuals
-
Snackbar 的可视数据。
no setter
Methods
-
dismiss(
) → Future< void> - 关闭 Snackbar。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performAction(
) → Future< void> - 执行 Snackbar 操作。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited