MiuixSnackbarDuration class sealed
Snackbar 显示时长。对应 Kotlin SnackbarDuration。
Constructors
- MiuixSnackbarDuration.custom(int durationMillis)
-
创建自定义显示时长;
durationMillis必须大于零。constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- indefinite → const MiuixSnackbarDuration
- 一直显示,直至主动关闭。
- long → const MiuixSnackbarDuration
- 长时显示(10000ms)。
- short → const MiuixSnackbarDuration
- 短时显示(4000ms)。