MiuixSnackbarVisuals class
Snackbar 的可视数据。对应 Kotlin SnackbarVisuals。
- Annotations
Constructors
- MiuixSnackbarVisuals({required String message, String? actionLabel, bool withDismissAction = false, MiuixSnackbarDuration duration = MiuixSnackbarDuration.short})
-
const
Properties
- actionLabel → String?
-
可选操作标签。
final
- duration → MiuixSnackbarDuration
-
显示时长。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
显示的消息文本。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- withDismissAction → bool
-
是否显示关闭操作。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited