MiuixTabRowColors class
对应 Kotlin TabRowColors 的颜色配置。
- Annotations
Constructors
- MiuixTabRowColors({required Color backgroundColor, required Color contentColor, required Color selectedBackgroundColor, required Color selectedContentColor})
-
const
Properties
- backgroundColor → Color
-
final
- contentColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedBackgroundColor → Color
-
final
- selectedContentColor → Color
-
final
Methods
-
background(
bool selected) → Color -
content(
bool selected) → Color -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited