MiuixTextFieldColors class

TextField 颜色配置。对应 Kotlin TextFieldColors。

Annotations

Constructors

MiuixTextFieldColors({required Color backgroundColor, required Color labelColor, required Color borderColor})
const

Properties

backgroundColor → Color
背景色。对应 Kotlin backgroundColor,默认 secondaryContainer。
final
borderColor → Color
聚焦边框色。对应 Kotlin borderColor,默认 primary。
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → Color
标签色。对应 Kotlin labelColor,默认 onSecondaryContainer。
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited