MiuixTextFieldDefaults class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

textFieldColors(BuildContext context) → MiuixTextFieldColors

Constants

borderWidth → const double
聚焦时边框宽度。
cornerRadius → const double
默认圆角。
insideMargin → const EdgeInsets
默认内边距(水平/垂直)。
labelFontSizeFloating → const double
标签浮动时字号。
labelFontSizeNormal → const double
标签正常时字号。