MiuixTextStyles class
Miuix 文本样式集。对应 Kotlin 端的 TextStyles。
所有样式的运行时颜色由 MiuixTheme 的 onBackground 提供,
这里仅保留字号/字重/行高。
- Annotations
Constructors
- MiuixTextStyles({required TextStyle main, required TextStyle paragraph, required TextStyle body1, required TextStyle body2, required TextStyle button, required TextStyle footnote1, required TextStyle footnote2, required TextStyle headline1, required TextStyle headline2, required TextStyle subtitle, required TextStyle title1, required TextStyle title2, required TextStyle title3, required TextStyle title4})
-
const
Properties
- body1 → TextStyle
-
正文 1:16sp。
final
- body2 → TextStyle
-
正文 2:14sp。
final
-
按钮:17sp。
final
- footnote1 → TextStyle
-
脚注 1:13sp。
final
- footnote2 → TextStyle
-
脚注 2:11sp。
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- headline1 → TextStyle
-
标题行 1:17sp。
final
- headline2 → TextStyle
-
标题行 2:16sp。
final
- main → TextStyle
-
主文本:17sp。
final
- paragraph → TextStyle
-
段落:17sp,行高 1.2em。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → TextStyle
-
副标题:14sp,加粗。
final
- title1 → TextStyle
-
标题 1:32sp。
final
- title2 → TextStyle
-
标题 2:24sp。
final
- title3 → TextStyle
-
标题 3:20sp。
final
- title4 → TextStyle
-
标题 4:18sp。
final
Methods
-
copy(
{TextStyle? main, TextStyle? paragraph, TextStyle? body1, TextStyle? body2, TextStyle? button, TextStyle? footnote1, TextStyle? footnote2, TextStyle? headline1, TextStyle? headline2, TextStyle? subtitle, TextStyle? title1, TextStyle? title2, TextStyle? title3, TextStyle? title4}) → MiuixTextStyles -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override