MiuixTextureBlur class

对 backdrop 提供的背景做模糊并叠加子内容。对应 Kotlin Modifier.textureBlur。

shape 决定裁剪形状(ShapeBorder,null=矩形);blurRadius 模糊半径(dp); colors 模糊后颜色调整;enabled 为 false 时直接画子内容。

Inheritance

Constructors

MiuixTextureBlur({Key? key, required MiuixBackdrop backdrop, ShapeBorder? shape, double blurRadius = MiuixBlurDefaults.blurRadius, BlurColors colors = const BlurColors(), bool enabled = true, Widget? child})
const

Properties

backdrop → MiuixBackdrop
final
blurRadius → double
final
child → Widget?
final
colors → BlurColors
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited