MiuixTooltipDefaults class

Tooltip 的尺寸、颜色和动画默认值。

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

plainTooltipContainerColor(BuildContext context) → Color
Plain Tooltip 使用反色表面。
plainTooltipContentColor(BuildContext context) → Color
richTooltipColors(BuildContext context) → MiuixRichTooltipColors