MiuixTooltipScope class
Tooltip 内容构建时可用的锚点信息。
- Annotations
Constructors
- MiuixTooltipScope({required MiuixTooltipAnchorPosition positioning, required Rect anchorBounds})
-
const
Properties
- anchorBounds → Rect
-
锚点在 Overlay 坐标系中的边界。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- positioning → MiuixTooltipAnchorPosition
-
当前实际采用的方位(已经过 RTL 解析及空间不足翻转)。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited