MiuixTooltipState class
控制 Tooltip 显隐的状态。
所有实例共享一个活动槽,因此同一时刻至多显示一个 Tooltip。非持久状态在 MiuixTooltipDefaults.tooltipDuration 后自动关闭。
- Inheritance
-
- Object
- ChangeNotifier
- MiuixTooltipState
Constructors
- MiuixTooltipState({bool initialIsVisible = false, bool isPersistent = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- initialIsVisible → bool
-
final
- isPersistent → bool
-
final
- isVisible → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dismiss(
) → void - 关闭 Tooltip。
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
show(
) → Future< void> - 显示 Tooltip,并在它关闭时完成返回的 Future。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited