MiuixTopAppBarDefaults class

TopAppBar 默认值。对应 Kotlin TopAppBarDefaults

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

actionIconPadding → const double
操作图标的末端内边距。
collapsedHeight → const double
折叠状态下 TopAppBar 的高度。
largeTitleBottomPadding → const double
无副标题时大标题的底部内边距。
导航图标的起始内边距。
smallTopAppBarCenterHeight → const double
SmallTopAppBar 的垂直中心高度。
subtitleBottomPadding → const double
副标题的底部内边距。
titlePadding → const double
标题水平内边距。
titleWidthFraction → const double
居中标题与导航/操作之间的横向余量比例。