MiuixWindowDropdownMenu class

窗口级下拉菜单(单分组)。对应 Kotlin WindowDropdownMenu(entry)。

Inheritance

Constructors

MiuixWindowDropdownMenu({Key? key, required MiuixDropdownEntry? entry, required String title, MiuixBasicComponentColors? titleColor, String? summary, MiuixBasicComponentColors? summaryColor, MiuixDropdownColors? dropdownColors, Widget? startAction, Widget? bottomAction, EdgeInsetsGeometry insideMargin = MiuixBasicComponentDefaults.insideMargin, double? maxHeight, bool enabled = true, bool? collapseOnSelection = true, ValueChanged<bool>? onExpandedChange})
const
MiuixWindowDropdownMenu.entries({Key? key, required List<MiuixDropdownEntry> entries, required String title, MiuixBasicComponentColors? titleColor, String? summary, MiuixBasicComponentColors? summaryColor, MiuixDropdownColors? dropdownColors, Widget? startAction, Widget? bottomAction, EdgeInsetsGeometry insideMargin = MiuixBasicComponentDefaults.insideMargin, double? maxHeight, bool enabled = true, bool? collapseOnSelection, ValueChanged<bool>? onExpandedChange})
窗口级下拉菜单(多分组)。对应 Kotlin WindowDropdownMenu(entries)。
const

Properties

bottomAction → Widget?
final
collapseOnSelection → bool?
final
final
effectiveEntries → List<MiuixDropdownEntry>
no setter
enabled → bool
final
entries → List<MiuixDropdownEntry>
final
entry → MiuixDropdownEntry?
final
hashCode → int
The hash code for this object.
no setterinherited
insideMargin → EdgeInsetsGeometry
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight → double?
final
onExpandedChange → ValueChanged<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startAction → Widget?
final
summary → String?
final
summaryColor → MiuixBasicComponentColors?
final
title → String
final
titleColor → MiuixBasicComponentColors?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited